==> apache-cxf-3.6.6-src.tar.gz: apache-cxf-3.6.6-src/rt/frontend/jaxws/src/test/java/org/apache/cxf/jaxws/support/JaxWsImplementorInfoTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.jaxws.support;

import javax.jws.WebService;
import javax.xml.ws.WebServiceProvider;

import org.apache.cxf.calculator.CalculatorImpl;

import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

public class JaxWsImplementorInfoTest {

    @Test
    public void testGetWSDLLocation() throws Exception {
        JaxWsImplementorInfo info = new JaxWsImplementorInfo(CalculatorImpl.class);
        assertEquals("testutils/calculator.wsdl", info.getWsdlLocation());
    }

    @Test
    public void testWebServiceAnnotation() throws Exception {
        assertTrue(JaxWsImplementorInfo.
                   ifAnnotationLoadedByOtherClassLoader(CalculatorImpl.class, WebService.class));
        assertFalse(JaxWsImplementorInfo.
                    ifAnnotationLoadedByOtherClassLoader(CalculatorImpl.class, WebServiceProvider.class));

    }
}

==> apache-cxf-4.1.3-src.tar.gz: apache-cxf-4.1.3-src/rt/frontend/jaxws/src/test/java/org/apache/cxf/jaxws/support/JaxWsImplementorInfoTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.jaxws.support;

import jakarta.jws.WebService;
import jakarta.xml.ws.WebServiceProvider;
import org.apache.cxf.calculator.CalculatorImpl;

import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

public class JaxWsImplementorInfoTest {

    @Test
    public void testGetWSDLLocation() throws Exception {
        JaxWsImplementorInfo info = new JaxWsImplementorInfo(CalculatorImpl.class);
        assertEquals("testutils/calculator.wsdl", info.getWsdlLocation());
    }

    @Test
    public void testWebServiceAnnotation() throws Exception {
        assertTrue(JaxWsImplementorInfo.
                   ifAnnotationLoadedByOtherClassLoader(CalculatorImpl.class, WebService.class));
        assertFalse(JaxWsImplementorInfo.
                    ifAnnotationLoadedByOtherClassLoader(CalculatorImpl.class, WebServiceProvider.class));

    }
}
